%------------------------------------------------------%
% Swathdesign.m                                        %
%------------------------------------------------------%
%  Function for creating a geometry file to be         %
%  used in VERES. Input is a SWATH main particulars    %
%  and output is a .mgf file for application in  VERES %
% ---------------------------------------------------- %
% Written by: Heine Groetting                          %
% Last edit: 22/02-15                                  %
% ---------------------------------------------------- %
% Input: -Hard coded main characteristics of SWATH     %
%------------------------------------------------------%
% Output: - mgf file for input in Veres                %
%         - x, containing x-coordinates of the         %
%           different sections.                        %
%         - HxP, containing height of pontoon as       %
%           function of x-coordinate                   %
%         - WxP, width of pontoon as function          %
%           of x-coordinate                            %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [HxP WxP x]=Swathdesign(a);
%---------Defining main particulars-----------------------------%
Lpp= 23 ;% [m] Length between perpendiculars
B= 10.6; % [m] Beam of vessel
Lwl= 24; % [m] Lengt in waterline
Dswath= 2.6; % [m]  Draft in SWATH mode
Dcat=   1.6 ; % [m] Draft in catamaran mode
Depth= 6.4 ; %  [m]Depth of vessel 
SWF=0.35; % [-] Width of strut as a fraction of width of pontoon
Lps=0.9; % [-] Length of struts as part of length of pontoons
Ns=31; % [-] Number of sections
Np=20; % [-]  Numer of points per section
WP=2.6; % [m] Width of Pontoon at the widest
HP= 2.2; % [m] Height of Pontoon at highest 
HPB=1.8; % [m] Height of pontoon at bow
HPS=1.2; % [m] Height of pontoon at stern
YP= (B-WP)*0.5;   % [m] Horizontal distance from centerline to centerline of pontoon
DX=Lwl/(Ns-1); % [m] Length between sections
BowInc=6 ; % [m] Distance where the pontoon is inclined in the bow;
SternInc=5; % [m] Distance where the pontoon is inclined in the stern;
SternHPS=3;   % [m] Distance where the pontoon have HPS;
NSternInc=floor(SternInc/DX); % [-] Number of sections pontoon inclined in stern
NBowInc=floor(BowInc/DX);% [-] Number of sections pontoon inclined in bow
%---------------------------------------------------------------%


HxP=[]; % [m] Height of pontoon as a function of section
WxS=[]; % [m] Width of strut as a function of section
WxP=[]; % [m] Width of pontoon as a function of section
Zcord=zeros(Np,Ns); % [m] (Np,Ns) Matrix containing z coordinate for point n section m  
Ycord=Zcord; % [m] (Np,Ns) Matrix containing y coordinate for point n section m

% 
teller=1;
for i=1:Ns
     x(i)=-Lwl*0.5+ (i-1)*DX;
     
     if x< -0.5*Lwl+BowInc
    HxP(i)=HPB+(Lwl*0.5+x(i))*(HP-HPB)/BowInc;
    
     else 
         if x< -0.5*Lwl+(Lwl-SternInc-SternHPS);
       HxP(i)=HP;
     
         else
            
             if  x< -0.5*Lwl+(Lwl-SternHPS);
             HxP(i)=HP-(x(i)-(Lwl*0.5-SternInc-SternHPS))*(HP-HPS)/SternInc;
             teller=teller+1;
             else
                 HxP(i)=HPS;
             end
         end
     end
     if x(i)>=0;
     WxP(i)=0.5*WP*sqrt(1-(x(i)/(0.5*Lwl))^2);
     else 
     WxP(i)=0.5*WP*cos(pi*x(i)/Lwl);
     end 
     
     WxS(i)=SWF*WxP(i); 
     teller2=1;
      for j=1:(Np*0.5)
          if j == (Np*0.5)
              Zcord(j,i)=HP-HxP(i);
              Ycord(j,i)=YP;
              Zcord(Np,i)=Depth;
              Ycord(Np,i)=0;

          elseif j==1
              Zcord(j,i)=Depth;
              Ycord(j,i)=YP+WxS(i);
              Zcord(Np-j,i)=Zcord(j,i);
              Ycord(Np-j,i)=YP-WxS(i);
          elseif j==2
              Zcord(j,i)=HP;
              Ycord(j,i)=YP+WxS(i);
              Zcord(Np-j,i)=Zcord(j,i);
              Ycord(Np-j,i)=YP-WxS(i);
          elseif j==3
              Zcord(j,i)=HP;
              Ycord(j,i)=YP+(WxP(i)-0.02);
              Zcord(Np-j,i)=Zcord(j,i);
              Ycord(Np-j,i)=YP-(WxP(i)-0.02);
          else
              temp1= 0.5*(Np-8);
              temp2=HxP(i)/(temp1+1);
              temp3=temp2* teller2;
              Zcord(j,i)=HP-temp2* teller2;
              Ycord(j,i)=YP+ WxP(i)*sqrt(1-(temp3/HxP(i))^2);
              Zcord(Np-j,i)=Zcord(j,i);
              Ycord(Np-j,i)=YP- WxP(i)*sqrt(1-(temp3/HxP(i))^2);
              teller2=teller2+1;
          end
          
          
      
      
      end 
      
   
  
     
      
end



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

fid=fopen('swath_35.mgf', 'w');
    fprintf(fid, 'VERES GEOMETRY FILE\n');
    fprintf(fid, 'SWATH OFFSHORE WINDTURBINE SERVICE VESSEL\n');
    fprintf(fid, ' Draught between 2.6 and 1.6\n');
    fprintf(fid, 'Author: Heine Groetting\n');
    fprintf(fid, '%f \n', Lpp);
for i=1:Ns

    fprintf(fid, '%i \n', Ns+1 -i); % SECTION number, beginning in the bow  
    fprintf(fid, '%f \n', x(i)); % Printing x position 
    fprintf(fid, '%i \n', Np); % Number of points per section
  
    for j=1:Np
     fprintf(fid, '%f %f\n', Ycord(j,i), Zcord(j,i));   
        
    end
    
   




end 

fclose(fid);
WxP=2*WxP;

end

