%-------------------------------------------------------------%
% doublespec.m                                                %
%-------------------------------------------------------------%
% Function that calculates the availability dividing the      %
% seastate in one swell and other wind generated part         %
% with respect to nora hindcast stored in wavedat.dat         %
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 27/02-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
%  Heta        - Transfer function for limiting downwards slip%
%  Hneta       - Transfer function for limiting upwards slip  %
%  SHeta       - Transfer function for limiting left slip     %
%  SHneta      - Transfer function for limiting right slip    %
%  wavedat.dat - Wave data for Dogger Bank location 2         % 
%  Racc        - Acceptable probability for failure per access%
%  h           - Water depth                                  %
%  omega       - Frequencies of Heta and Hneta                %
%  my          - Friction coefficient between fender and mill %
%  Fbollard    - Amount of bollard thrust                     % 
%  beta        - Vector with the wave headings considered     %
%  Rtransf     - Transfer function for roll motion            %
%  Rollmax     - Maximum acceptable roll angle                %
%  TMA_vector  - Vector containing if access can be made      %
%                according to the calculation with the TMA    % 
%                spectrum                                     %
%-------------------------------------------------------------%
% Output:                                                     %
% avblty_2spc_W   - Winter availability obtained              %
% avblty_2spc     - Overall availability                      %
% diffdec         - Part of seastates found acceptable by use %
%                   of the TMA spectrum that was not approved %
%                   by the  two spectrum method               %
%-------------------------------------------------------------%



function [avblty_2spc_W avblty_2spc diffdec]=doublespec(Racc,Heta,Hneta,h,my,Fbollard,omega,gma,beta,Rtransf,Rollmax,TMA_vector,gmaS,SHeta, SHneta)
A=load('wavedat.dat'); % A becomes a matrix containing the wave data
Hs=A(:,1); % Vector containing the signinficant waveheights 
Tp=A(:,2);  % Vector containing the peak periods
Mdir=A(:,3); % Vector containing the mean direction
HsS=A(:,4); % Vector containing the significant waveheight of swell part of waves
TpS=A(:,5);  % Vector containing the the peak periods of swell
MdirS=A(:,6); % Mean direction of swell
HsW=A(:,7); % Vector containing the significant waveheight of windsea
TpW=A(:,8); % Vector containing the peak periods of wind sea
MdirW=A(:,9); % Mean direction of windsea
month=A(:,10); % Month of record
Nseas=length(Hs); % Number of seastates

Avteller=0;
UAteller=0;
Wteller=0;
AWteller=0;
lim=my*Fbollard;
roll_teller=0;
dw_teller=0;
up_teller=0;
gmaW=1;
diffdec=0;
for i=1:Nseas
  Nsycle=1800/Tp(i); % Approximation of number of cycles during one access operation
  Racc_1cycle=Racc/Nsycle ; % Acceptable probability of slip per cycle
  
[Swind Sjon Spm]=specter(HsW(i),TpW(i), h,omega, gmaW); 
[Sswell Sjon Spm]=specter(HsS(i),TpS(i), h,omega, gmaS); 
    if or((MdirS(i)>=338),(MdirS(i)<=23))
    betacordS=1;% _Head sea
    elseif or((MdirS(i)>=293),(MdirS(i)<=68))
    betacordS=2; %Quartering head sea
    elseif or((MdirS(i)>=247),(MdirS(i)<=113))
    betacordS=3;% Beam sea
    elseif or((MdirS(i)>=203),(MdirS(i)<=158))
    betacordS=4; % Quartering following sea
    else
    betacordS=5; % Following sea
    end
    
    if or((MdirW(i)>=338),(MdirW(i)<=23))
    betacordW=1;% _Head sea
    elseif or((MdirW(i)>=293),(MdirW(i)<=68))
    betacordW=2; %Quartering head sea
    elseif or((MdirW(i)>=247),(MdirW(i)<=113))
    betacordW=3;% Beam sea
    elseif or((MdirW(i)>=203),(MdirW(i)<=158))
    betacordW=4; % Quartering following sea
    else
    betacordW=5; % Following sea
    end
   stdev_eta=doublestdev(Heta(:,betacordW),Swind,Heta(:,betacordS),Sswell,omega,beta);
   stdev_neta=doublestdev(Hneta(:,betacordW),Swind,Hneta(:,betacordS),Sswell,omega,beta);
   stdev_roll=doublestdev(Rtransf(:,betacordW),Swind,Rtransf(:,betacordS),Sswell,omega,beta);
   stdev_seta=doublestdev(Heta(:,betacordW),Swind,SHeta(:,betacordS),Sswell,omega,beta);
   stdev_sneta=doublestdev(Hneta(:,betacordW),Swind,SHneta(:,betacordS),Sswell,omega,beta);
   dw_probfail=exp(-lim^2/(2*stdev_eta^2));
   up_probfail=exp(-lim^2/(2*stdev_neta^2));
   roll_probfail=exp(-Rollmax^2/(2*stdev_roll^2));
   left_probfail=exp(-lim^2/(2*stdev_seta^2));
   right_probfail=exp(-lim^2/(2*stdev_sneta^2));
   probfail=1-(1-dw_probfail)*(1-up_probfail)*(1-roll_probfail)*...
       (1-left_probfail)*(1-right_probfail);
    if or(month(i)==12,month(i)<4);
    Wteller=Wteller+1;
    end
    
     if  probfail>Racc_1cycle
         UAteller=UAteller+1;
         if TMA_vector(i)
             diffdec=diffdec+1;
         end
     else
         Avteller=Avteller+1;
        
             if or(month(i)==12,month(i)<4);
             AWteller=AWteller+1;
             end

     end

end
avblty_2spc_W=AWteller/Wteller;
avblty_2spc=Avteller/Nseas;

diffdec=diffdec/sum(TMA_vector);

end
