%-------------------------------------------------------------%
% fendertransf.m                                              %
%-------------------------------------------------------------%
% Function that calculates the relevant transfer functions    %
% as a function of frequency and wave heading                 %
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 27/02-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
% M     - 6x6 mass matrix                                     %
% C     - 6x6 hydrostatic stiffness matrix                    %
% A     - 6*Nx6 added mass matrices                           %
% B     - 6*Nx6 damping matrices                              %
% Frao  - 6*NxM                                               %
% omega - Nx1 vector containing frequensies                   %
% beta  - Mx1 vector containing headings                      %
% AccP  - Point of access                                     %
% my    - Friction coefficient between vessel and turbine     %
%-------------------------------------------------------------%
% Output:                                                     %
% Heta   - Transfer function for eta, variable that describes %
%          limit for downward slip. Function of frequency and %
%          wave direction. Nfreq x Nhead                      %
% SHneta  -Transfer function for sneta, variable thatdescribes%
%          limit for sideways slip . Function of frequency and%
%          wave direction. Nfreq x Nhead                      %
% SHeta   -Transfer function for seta, variable thatdescribes %
%          limit for sideways slip. Function of frequency and %
%          wave direction. Nfreq x Nhead                      %
% Hneta  - Transfer function for neta, variable that describes%
%          limit for upward slip . Function of frequency and  %
%          wave direction. Nfreq x Nhead                      % 
% Rtransf- Transfer function for roll angle. Function of      %
%          frequency and wave direction. Nfreq x Nhead        %
% J1     - Transfer function for normal force in fender       %
% J2     - Transfer function for sideways force in fender     %
% J3     - Transfer function for vertical force in fender     %
%-------------------------------------------------------------%
function [Heta Hneta Rtransf J1 J2 J3 SHeta SHneta Ptransf]=fendertransf(A,M,C,B,Frao,omega,beta,AccP,my,Fv)

Heta=[];
Hneta=[];
Rtransf=[];
P1=[];% Joint force in x,y,z direction. Consists of J1,J2 and J3
J1=[];
J2=[];
J3=[]; 
Xacc=AccP(1);
Yacc=AccP(2);
Zacc=AccP(3);

Q=[0 -Zacc Yacc; Zacc 0 -Xacc; -Yacc Xacc 0];
RQ=-Q;
Nfreq=length(omega);
Nhead=length(beta);
if Fv==0
    Fv=zeros(6*Nfreq,Nhead);
end
teller=1;
img=1i;
for i=1:Nhead 
    temp1=(i-1)*6;
    for j=1:Nfreq 
    temp2=(j-1)*6;
    tempA=A((temp2+1):(temp2+6), 1:6); % Added mass matrix for given frequency
    tempB=B((temp2+1):(temp2+6), 1:6); % Damping matrix for given frequency
    tempFraov=Fv((temp2+1):(temp2+6), i);
    tempFraov=real(tempFraov).*cosd(imag(tempFraov))+real(tempFraov).*sind(imag(tempFraov)).*img;
    tempFrao=Frao((temp2+1):(temp2+6), i); % Excitation force Rao for given frequency and direction
    tempFrao=real(tempFrao).*cosd(imag(tempFrao))+real(tempFrao).*sind(imag(tempFrao)).*img+tempFraov;
    G=-omega(j)^2*(M+tempA)+omega(j)*tempB*1i+C;
    H=(G(1:3,1:3)*Q+G(1:3,4:6))*inv(G(4:6,1:3)*Q+G(4:6,4:6)-Q*G(1:3,1:3)*Q-Q*G(1:3,4:6));
    P1=H*(tempFrao(4:6)-Q*tempFrao(1:3))- tempFrao(1:3);
    Heta(j,i)=P1(3)-my*P1(1);
    Hneta(j,i)=-(P1(3)+my*P1(1));
    R2=inv(G(4:6,1:3)*Q+G(4:6,4:6))*(tempFrao(4:6)+Q*P1);
    Rtransf(j,i)=R2(1);
    Ptransf(j,i)=R2(2);
    SHeta(j,i)=P1(2)-my*P1(1);
    SHneta(j,i)=-(P1(2)+my*P1(1));
    J1(j,i)=P1(1);
    J2(j,i)=P1(2);
    J3(j,i)=P1(3);
    end   
end


end
