%-------------------------------------------------------------%
% limHs2.m                                                    %
%-------------------------------------------------------------%
% Function that calculates limiting significant waveheight as %
% function of wave frequency and direction                    %
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 17/03-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
% Heta    - Transfer function for eta, variable that describes%
%           limit for downward slip. Function of frequency and%
%            wave direction. Nfreq x Nhead                    %
% Hneta   - Transfer function for neta,variable that describes%
%           limit for upward slip . Function of frequency and %
%           wave direction. Nfreq x Nhead                     %
% SHneta  -Transfer function for sneta, variable thatdescribes%
%          limit for sideways slip . Function of frequency and%
%          wave direction. Nfreq x Nhead                      %
% SHeta   -Transfer function for seta, variable thatdescribes %
%          limit for sideways slip. Function of frequency and %
%          wave direction. Nfreq x Nhead                      %
% Racc    - Acceptable probability for failure during one     %
%           seastate                                          %
% gma     - Peakness factor for JONSWAP spectrum              %
% h       - Water depth [m]                                   %
% omega   - Wave frequencies                                  % 
% beta    - Wave headings                                     %
% Fbollard- Bollard force[N]                                  % 
% my      - Friction coefficient for fender                   %
% Hsmax   - Maximum significant wave height considered        %
% Rollmax - Maximum acceptable roll angle                     %
% Rtransf - Roll transfer function                            %
%-------------------------------------------------------------%
% Output:                                                     %
%  LHS_TMA - Matrix containing limiting significant waveheight%
%            as function of peak frequency and wave heading   %
%            calculated by use of the TMA spectrum            %
%  LHS_JON - Same as LHS_TMA but with use of JONSWAP          %
%-------------------------------------------------------------%
function [LHS_TMA LHS_JON ]=limHs2(Heta,Hneta,Racc,gma,h,omega,beta,Fbollard,my,Hsmax,Rollmax,Rtransf,SHeta, SHneta);
LHS_TMA=[];
LHS_JON=[];
Tp=[2:0.5:20];
lim=my*Fbollard;
for j=1:length(beta) % wave headings
for i=1:length(Tp)
 
  Nsycle=1800/Tp(i); % Approximation of number of cycles during one access operation
  %%%%%% WORKING UNDER THE 0.5HOUR OPERATION ASSUMPTION %%%%%%%%%
  Racc_1cycle=Racc/Nsycle ; % Acceptable probability of slip per cycle
  runTMA=1;
  runJON=1;
  run=1;
  Hs=0.1;
while run~=0;
 [Stma Sjon Spm]=specter(Hs,Tp(i), h,omega, gma) ;
     TMAstdv_eta=stdev(Heta(:,j),Stma,omega);
     TMAstdv_neta=stdev(Hneta(:,j),Stma,omega);
     TMAstdv_seta=stdev(SHeta(:,j),Stma,omega);
     TMAstdv_sneta=stdev(SHneta(:,j),Stma,omega);
     TMAstdv_roll=stdev(Rtransf(:,j),Stma,omega);
     JONstdv_eta=stdev(Heta(:,j),Sjon,omega);
     JONstdv_neta=stdev(Hneta(:,j),Sjon,omega);
     JONstdv_seta=stdev(SHeta(:,j),Sjon,omega);
     JONstdv_sneta=stdev(SHneta(:,j),Sjon,omega);
     JONstdv_roll=stdev(Rtransf(:,j),Sjon,omega);
     
     TMAdw_probfail=exp(-lim^2/(2*TMAstdv_eta^2));
     TMAup_probfail=exp(-lim^2/(2*TMAstdv_neta^2));
     TMA_rollfail=exp(-Rollmax^2/(2*TMAstdv_roll^2));
     TMAle_probfail=exp(-lim^2/(2*TMAstdv_seta^2));
     TMAri_probfail=exp(-lim^2/(2*TMAstdv_sneta^2));
     JONdw_probfail=exp(-lim^2/(2*JONstdv_eta^2));
     JONup_probfail=exp(-lim^2/(2*JONstdv_neta^2));
     JON_rollfail=exp(-Rollmax^2/(2*JONstdv_roll^2));
     JONle_probfail=exp(-lim^2/(2*JONstdv_seta^2));
     JONri_probfail=exp(-lim^2/(2*JONstdv_sneta^2));
     TMA_probfail=1-(1-TMAup_probfail)*(1-TMAdw_probfail)*(1-TMAle_probfail)*...
         (1-TMAri_probfail)*(1-TMA_rollfail);
          JON_probfail=1-(1-JONup_probfail)*(1-JONdw_probfail)*(1-JONle_probfail)*...
         (1-JONri_probfail)*(1-JON_rollfail);
if runTMA    
    if  TMA_probfail>Racc_1cycle
    runTMA =0;
    LHS_TMA(i,j)=Hs-0.05;
    run=run-0.5;

    end
       

 end

if runJON    
    if  JON_probfail>Racc_1cycle
    runJON =0;
    LHS_JON(i,j)=Hs-0.05;
    run=run-0.5;
    end
end
Hs=Hs+0.1;
if Hs>=Hsmax %%%%% *Introducing  a maximum Hs%%%%%
    run=0;
   if runTMA
       LHS_TMA(i,j)=Hs;
       runTMA =0;
   end
   if runJON
       LHS_JON(i,j)=Hs;
       runJON =0;
   end
end

end
end
end
end 
