%-------------------------------------------------------------%
% specter.m                                                   %
%-------------------------------------------------------------%
% Function that generates a TMA and a JONSWAP spectrum given  %
% Hs, Tp and depth. Spectras are defined as in RP C205 by DNV %
%-------------------------------------------------------------%
% Author: Heine Groetting                                     %
%-------------------------------------------------------------%
% Last edit: 17/03-15                                         %
%-------------------------------------------------------------%
% Input:                                                      %
% Tp - Peak period                                            %
% Hs - Significant waveheight                                 %
% h  - Occean depth                                           %
% gma - gammafactor in the JONSWAP spectrum                   %
% omega - wave frequencies                                    %
%-------------------------------------------------------------%
% Output:                                                     %
% Stma - TMA specter                                          %
% Sjon - JONSWAP specter                                      %
% Spm  - PM specter                                           %
%-------------------------------------------------------------%
function [Stma Sjon Spm]=specter(Hs,Tp, h,omega,gma) 

Stma=[]; % TMA spetrum
Sjon=[]; % JONSWAP spectrum
Spm=[]; % PM spectrum
Agamma=1-0.287*log(gma); % Normalizing factor, log means natural algorithm in MATLAB
wP=2*pi/Tp;
w=omega;
krav=10^-6; % Accuracy in the wave number iteration
diff=1;  % just to get the wave number iteration started
g=9.81;  % Acceleration of gravity

for i=1: length(w)
    
    if w(i)< wP
        sigma=0.07; % Width parameter of JONSWAP Spectrum
    else
        sigma=0.09;
    end
    Spm(i) = (5/16)*Hs^2*wP^4*(w(i)^-5)*exp(-1.25*(w(i)/wP)^-4); 
    
    Sjon(i)=Agamma*Spm(i)*gma^(exp(-0.5*((w(i)-wP)/(sigma*wP))^2));
    
    %********** Wave number iteration ***************%
    k=w(i)^2/g;
    while diff>krav

    knew=w(i)^2/(g*tanh(k*h)); % The dispersion relation
    diff=abs(knew-k);
    k=knew;
    end
    TMA= (cosh(k*h))^2/((cosh(k*h))^2+w(i)^2*h/g);
    Stma(i)=Sjon(i)*TMA;
    %************************************************%
    
end 


end

